pub async fn auth(
user_provider: Option<UserProviderRef>,
header: Option<&RequestHeader>,
query_ctx: &QueryContextRef,
) -> Result<UserInfoRef>Expand description
Authenticate the user based on the header and query context.
pub async fn auth(
user_provider: Option<UserProviderRef>,
header: Option<&RequestHeader>,
query_ctx: &QueryContextRef,
) -> Result<UserInfoRef>Authenticate the user based on the header and query context.